.. vim: set ft=rst fenc=utf-8 tw=72 nowrap:

***********************
Introduction to PynFact
***********************

Information
===========

PynFact is an static weblog generator with a goal of simplicity and just
the needed features.  This project was born out of necessity, to
generate an static web site in a very minimalistic way, and with only
the options that are required in order to accomplish that task.

Why this name?
==============

Granted it will be used on the "web", the word "log" in Latin may be
translated as *INdicem FACTorum*, hence *InFact* or *-nFact* to be more
easily pronounceable when prepending the prefix ``py-``, an indicator of
the programming language where it has been developed.  In essence,
*PynFact* is saying: "In fact, a blog out of Python."

Also, ``pyblog``, ``pyblic``, ``pyweblog`` and many other cool names
were already taken.

Contributing
============

PynFact performs a small task and, therefore, there are no aspirations
of being a huge project, but that doesn't mean that it's not going to be
developed in an active way.  Contributors are very much appreciated and
always welcome.

If you find a bug (there are currently lots, since this is a early stage
version), feel free to report it using the GitHub `issue tracker`_ for
this project.

Check the ``TODO.md`` list to see if some of your suggestions are
already there, or bring that suggestion to my attention.


.. _`issue tracker`: https://github.com/jacorbal/pynfact/issues
